
Settings
========


.. automodule:: opendssdirect.Settings
            :members:
            :undoc-members:
            :show-inheritance:

.. function:: opendssdirect.Settings.AllocationFactors

    Set all load allocation factors for all loads defined by XFKVA property to this value.

.. function:: opendssdirect.Settings.AllowDuplicates

    Get if OpenDSS allows duplicate names of objects: {1 allow, 0 not allow}.Set if OpenDSS allows duplicate names of objects: {1 allow, 0 not allow}.

.. function:: opendssdirect.Settings.AutoBusList

    Get the list of Buses or (File=xxxxx) syntax for the AutoAdd solution mode.Set the list of Buses or (File=xxxxx) syntax for the AutoAdd solution mode.

.. function:: opendssdirect.Settings.CktModel

    Get {dssMultiphase* | dssPositiveSeq} Indicate if the circuit model is positive sequence.Set {dssMultiphase* | dssPositiveSeq} Indicate if the circuit model is positive sequence.

.. function:: opendssdirect.Settings.EmergVmaxpu

    Get the per unit maximum voltage for Emergency conditions.Set the per unit maximum voltage for Emergency conditions.

.. function:: opendssdirect.Settings.EmergVminpu

    Get the per unit minimum voltage for Emergency conditions.Set the per unit minimum voltage for Emergency conditions.

.. function:: opendssdirect.Settings.LossRegs

    Get the array of Integers defining Energy Meter registers to use for computing Losses.

.. function:: opendssdirect.Settings.LossWeight

    Get the weighting factor applied to Loss register values.Set the weighting factor applied to Loss register values.

.. function:: opendssdirect.Settings.NormVmaxpu

    Get the per unit maximum voltage for Normal conditions.Set the per unit maximum voltage for Normal conditions.

.. function:: opendssdirect.Settings.NormVminpu

    Get the per unit minimum voltage for Normal conditions.Set the per unit minimum voltage for Normal conditions.

.. function:: opendssdirect.Settings.PriceCurve

    Get the name of LoadShape object that serves as the source of price signal data for yearly simulations, etc.Set the name of LoadShape object that serves as the source of price signal data for yearly simulations, etc.

.. function:: opendssdirect.Settings.PriceSignal

    Get the price signal for the circuit.Set the price signal for the circuit.

.. function:: opendssdirect.Settings.Trapezoidal

    Get {True (1) | False (0)} value of trapezoidal integration flag in Energy Meters.Set {True (1) | False (0)} value of trapezoidal integration flag in Energy Meters.

.. function:: opendssdirect.Settings.UERegs

    Get the array of Integers defining Energy Meter registers to use for computing UE.

.. function:: opendssdirect.Settings.UEWeight

    Get the weighting factor applied to UE register values.Set the weighting factor applied to UE register values.

.. function:: opendssdirect.Settings.VoltageBases

    Get the array of doubles defining the legal voltage bases in kV L-L.

.. function:: opendssdirect.Settings.ZoneLock

    Get the status of Lock zones on energy Meters to prevent rebuilding if a circuit change occurs: {1= true, 0= False}.Set the status of Lock zones on energy Meters to prevent rebuilding if a circuit change occurs: {1= true, 0= False}.

